﻿/*
    Name............Create Target Camera
    Version.........1.0
    Description....Create a camera target to null object.
    Additional......Thanks for the scripting template by Lian.
*/


(function(){

    /*---------------------------------------------------------------------------------------------------------*/    
    function initGlobals(G) 
    /*---------------------------------------------------------------------------------------------------------*/
    {                
        G.NAME                      =   "CreateTargetCamera.jsx";
        G.TITLE                     =   "Create Target Camera";
        //-----------------------------------------------------------------------------------------------------
        G.NO_PROJ_ERR               =   {en:"Open a project first.", jp:"プロジェクトを開いて下さい."};
        G.NO_COMP_ERR               =   {en:"Select a composition.", jp:"コンポジションを選択して下さい."};
        G.NO_LAYER_ERR              =   {en:"Select at least one layer.", jp:"少なくとも1つのレイヤーを選択して下さい."};
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function loc(str) // 言語(日本語or英語)
    /*---------------------------------------------------------------------------------------------------------*/
    {
        return app.language == Language.JAPANESE ? str["jp"] : str["en"];
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function throwMsg(msg) // errorをalert
    /*---------------------------------------------------------------------------------------------------------*/
    {
        alert(loc(msg), G.TITLE);
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function addTargetCameraFunc(comp)
    /*---------------------------------------------------------------------------------------------------------*/
    {
        var targetCamera = comp.layers.addCamera('Target Camera',[0,0]);
        var targetNull = comp.layers.addNull();
        targetNull.threeDLayer = true;
        targetNull.name = 'Camera.target';
        targetCamera.pointOfInterest.expression = 'thisComp.layer("Camera.target").position;';
        targetCamera.focusDistance.expression = "target = thisComp.layer('Camera.target');V1 = target.toWorld(target.anchorPoint) - toWorld([0,0,0]);V2 = toWorldVec([0,0,1]);dot(V1,V2);";
     }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function main() 
    /*---------------------------------------------------------------------------------------------------------*/
    {
        // プロジェクトを開いているかチェック
        var proj = app.project;
        if (!proj) {
            throwMsg(G.NO_PROJ_ERR);
            return;
        }
        // コンポジションを選択してるかチェック
        var comp = proj.activeItem;
        if (!comp || !(comp instanceof CompItem)) {
            throwMsg(G.NO_COMP_ERR);
            return;
        }
        // レイヤーを少なくとも1つ選択してるかチェック
//        if (comp.selectedLayers.length < 1){
//            throwMsg(G.NO_LAYER_ERR);
//            return;
//        }
        
        // メイン処理であるaddTargetCameraFunc()関数を実行
        app.beginUndoGroup(G.TITLE);
        addTargetCameraFunc(comp);
        app.endUndoGroup();
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    // Entry Point
    /*---------------------------------------------------------------------------------------------------------*/
    
    var G = new Object();
    initGlobals(G);
    main();

})();
